==> carbon-components-react-0.2.8.tgz: package/es/components/TourTooltip/TourTooltip-test.js <==
import React from 'react';
import TourTooltip from '../TourTooltip';
import { shallow } from 'enzyme';
import Checkbox from '../Checkbox';
describe('TourTooltip', function () {
  describe('default configuration', function () {
    var description = "This is the tooltip's description.";
    var wrapper = shallow(React.createElement(TourTooltip, {
      onNext: function onNext() {
        return alert('next');
      },
      onClose: function onClose() {
        return alert('close');
      },
      onPrev: function onPrev() {
        return alert('prev');
      },
      description: description
    }));
    it('renders the tooltip as expected', function () {
      expect(wrapper.children.length).toEqual(1);
    });
    it('contains a checkbox by default', function () {
      expect(wrapper.find(Checkbox).length).toEqual(1);
    });
    it('contains three buttons by default', function () {
      expect(wrapper.find('button').length).toEqual(3);
    });
    it('contains the description text', function () {
      var descRegExp = new RegExp(description);
      expect(descRegExp.test(wrapper.text())).toEqual(true);
    });
  });
  describe('hide functionality options', function () {
    var description = "This is the tooltip's description.";
    var wrapper = shallow(React.createElement(TourTooltip, {
      onNext: function onNext() {
        return alert('next');
      },
      onClose: function onClose() {
        return alert('close');
      },
      onPrev: function onPrev() {
        return alert('prev');
      },
      hidePrev: true,
      hideClose: true,
      hideCheckbox: true,
      description: description
    }));
    it('still renders the tooltip', function () {
      expect(wrapper.length).toEqual(1);
    });
    it('only has a single button', function () {
      expect(wrapper.find('button').length).toEqual(1);
    });
    it('does not have a checkbox', function () {
      expect(wrapper.find(Checkbox).length).toEqual(0);
    });
  });
});

==> carbon-components-react-0.8.1.tgz: package/es/components/TourTooltip/TourTooltip-test.js <==
import React from 'react';
import TourTooltip from '../TourTooltip';
import { shallow } from 'enzyme';
describe('TourTooltip', function () {
  describe('default configuration', function () {
    var description = "This is the tooltip's description.";
    var wrapper = shallow( /*#__PURE__*/React.createElement(TourTooltip, {
      onNext: function onNext() {
        return alert('next');
      },
      onClose: function onClose() {
        return alert('close');
      },
      onPrev: function onPrev() {
        return alert('prev');
      },
      description: description
    }));
    it('renders the tooltip as expected', function () {
      expect(wrapper.children.length).toEqual(1);
    });
    it('contains two buttons by default', function () {
      expect(wrapper.find('button').length).toEqual(2);
    });
  });
  describe('hide functionality options', function () {
    var description = "This is the tooltip's description.";
    var wrapper = shallow( /*#__PURE__*/React.createElement(TourTooltip, {
      onNext: function onNext() {
        return alert('next');
      },
      onClose: function onClose() {
        return alert('close');
      },
      onPrev: function onPrev() {
        return alert('prev');
      },
      hidePrev: true,
      description: description
    }));
    it('still renders the tooltip', function () {
      expect(wrapper.length).toEqual(1);
    });
    it('only has a single button', function () {
      expect(wrapper.find('button').length).toEqual(1);
    });
  });
});
